==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Mtr0.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mtr0:
	"""Mtr0 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mtr0", core, parent)

	def set(self, mtr_0: enums.NfcMinTr0, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:MTR0 \n
		Sets the minimum value of TR0 supported. \n
			:param mtr_0: TR00| TR01| TR02
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(mtr_0, enums.NfcMinTr0)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR0 {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcMinTr0:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:MTR0 \n
		Sets the minimum value of TR0 supported. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: mtr_0: TR00| TR01| TR02"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR0?')
		return Conversions.str_to_scalar_enum(response, enums.NfcMinTr0)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Mtr0.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mtr0:
	"""Mtr0 commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mtr0", core, parent)

	def set(self, mtr_0: enums.NfcMinTr0, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:MTR0 \n
		Snippet: driver.source.bb.nfc.cblock.mtr0.set(mtr_0 = enums.NfcMinTr0.TR00, channel = repcap.Channel.Default) \n
		Sets the minimum value of TR0 supported. \n
			:param mtr_0: TR00| TR01| TR02
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(mtr_0, enums.NfcMinTr0)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR0 {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcMinTr0:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:MTR0 \n
		Snippet: value: enums.NfcMinTr0 = driver.source.bb.nfc.cblock.mtr0.get(channel = repcap.Channel.Default) \n
		Sets the minimum value of TR0 supported. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: mtr_0: TR00| TR01| TR02"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:MTR0?')
		return Conversions.str_to_scalar_enum(response, enums.NfcMinTr0)
